==> janus-config-1.2.2.16-sources.jar: com/xforceplus/janus/config/core/util/Constant.java <==
package com.xforceplus.janus.config.core.util;

/**
 * @Author: xuchuanhou
 * @Date:2022/4/2下午4:59
 */
public class Constant {

    public static final String UPLOAD_TYPE_SYNTABLE="uploadDbTables";
    public static final String UPLOAD_TYPE_MONITORNOTICE="monitorNotice";
    public static final String UPLOAD_TYPE_ACCEPTSTATICS="acceptStatics";

    public static final  String KEY_SERIALNO="serialNo";

    /** 字符串类型 */
    public static final String TYPE_STRING = "String";

    /** 整型 */
    public static final String TYPE_INTEGER = "Integer";

    /** 长整型 */
    public static final String TYPE_LONG = "Long";

    /** 浮点型 */
    public static final String TYPE_DOUBLE = "Double";

    /** 高精度计算类型 */
    public static final String TYPE_BIGDECIMAL = "BigDecimal";

    public static final String TYPE_NUMBER = "Number";

    /** 时间类型 */
    public static final String TYPE_DATE = "Date";

    /** boolean */
    public static final String TYPE_BOOLEAN = "Boolean";

    /** array */
    public static final String TYPE_ARRAY = "Array";
    /** 系统引用对象 */
    public static final String TYPE_OBJ = "Object";
    /** 系统引用对象 */
    public static final String TYPE_MAP = "Map";


    public static final String LOCK_TYPE_LOCAL="1";
    public static final String LOCK_TYPE_DB="2";
    public static final String LOCK_TYPE_REDIS="3";


    public static final String SM2= "sm2";

    public static final String GM= "gm";


    public static final String AES = "aes";

    public static final String DATA_CODE_BASE64 = "BASE64";

    public static final String DATA_CODE_HEX = "HEX";

    public static final String MD5 = "MD5";

    public static final String EC = "EC";

    public static final String FIELD_BIG_DATA_TASK_ID="big-data-split-task-id";
    public static final String FIELD_BIG_DATA_COUNT="big-data-split-count";
    public static final String FIELD_BIG_DATA_INDEX="big-data-split-index";
    public static final String FIELD_BIG_DATA_ONLY_INVOKE = "big-data-split-only-invoke";

    /**集成框架**/
    public static final String CLIENT_TYPE_FRAMEWORK="2";
    /**连接器*/
    public static final String CLIENT_TYPE_STANDARD="3";
    /**
     * 用于记录集成平台消息sdk版本
     */
    public static final String JANUS_MSG_SDK_VERSION="4";


}

==> janus-config-1.2.3.0-sources.jar: com/xforceplus/janus/config/core/util/Constant.java <==
package com.xforceplus.janus.config.core.util;

/**
 * @Author: xuchuanhou
 * @Date:2022/4/2下午4:59
 */
public class Constant {

    public static final String UPLOAD_TYPE_SYNTABLE="uploadDbTables";
    public static final String UPLOAD_TYPE_MONITORNOTICE="monitorNotice";
    public static final String UPLOAD_TYPE_ACCEPTSTATICS="acceptStatics";

    public static final  String KEY_SERIALNO="serialNo";

    /** 字符串类型 */
    public static final String TYPE_STRING = "String";

    /** 整型 */
    public static final String TYPE_INTEGER = "Integer";

    /** 长整型 */
    public static final String TYPE_LONG = "Long";

    /** 浮点型 */
    public static final String TYPE_DOUBLE = "Double";

    /** 高精度计算类型 */
    public static final String TYPE_BIGDECIMAL = "BigDecimal";

    public static final String TYPE_NUMBER = "Number";

    /** 时间类型 */
    public static final String TYPE_DATE = "Date";

    /** boolean */
    public static final String TYPE_BOOLEAN = "Boolean";

    /** array */
    public static final String TYPE_ARRAY = "Array";
    /** 系统引用对象 */
    public static final String TYPE_OBJ = "Object";
    /** 系统引用对象 */
    public static final String TYPE_MAP = "Map";


    public static final String LOCK_TYPE_LOCAL="1";
    public static final String LOCK_TYPE_DB="2";
    public static final String LOCK_TYPE_REDIS="3";


    public static final String SM2= "sm2";

    public static final String GM= "gm";


    public static final String AES = "aes";

    public static final String DATA_CODE_BASE64 = "BASE64";

    public static final String DATA_CODE_HEX = "HEX";

    public static final String MD5 = "MD5";

    public static final String EC = "EC";

    public static final String SHA1 = "SHA1";
    public static final String SHA256 = "SHA256";
    public static final String SHA384 = "SHA384";
    public static final String SHA512 = "SHA512";

    public static final String FIELD_BIG_DATA_TASK_ID="big-data-split-task-id";
    public static final String FIELD_BIG_DATA_COUNT="big-data-split-count";
    public static final String FIELD_BIG_DATA_INDEX="big-data-split-index";
    public static final String FIELD_BIG_DATA_ONLY_INVOKE = "big-data-split-only-invoke";

    /**集成框架**/
    public static final String CLIENT_TYPE_FRAMEWORK="2";
    /**连接器*/
    public static final String CLIENT_TYPE_STANDARD="3";
    /**
     * 用于记录集成平台消息sdk版本
     */
    public static final String JANUS_MSG_SDK_VERSION="4";


}
